import{c as r,a0 as c,p as i,g as u,u as d,j as p,y as f,z as v,B as m,J as _,k as C,A as y,Y as g}from"./index-0b85ac09.js";import{a as k}from"./ListItem-13203a50.js";/* empty css              */import{a as P,d as V,i as h}from"./VImg-0b02a672.js";const $={props:{variant:{type:String,default:"default",validator:e=>["default","panel"].includes(e)}},setup(e,n){const a=r(()=>({class:"container-default"})),t=r(()=>({class:c.theme.current.value.dark?"container-default container-panels-dark":"container-default container-panels-light"}));return{btnProps:r(()=>{switch(e.variant){case"default":return a.value;case"panel":return t.value;default:return a.value}})}}};const w=i({fluid:{type:Boolean,default:!1},...P(),...V()},"VContainer"),x=u()({name:"VContainer",props:w(),setup(e,n){let{slots:a}=n;const{rtlClasses:t}=d();return h(()=>p(e.tag,{class:["v-container",{"v-container--fluid":e.fluid},t.value,e.class],style:e.style},a)),{}}});function B(e,n,a,t,o,l){return f(),v(x,C(t.btnProps,{variant:"default",fluid:""}),m({_:2},[_(e.$slots,(b,s)=>({name:s,fn:y(()=>[g(e.$slots,s)])}))]),1040)}const A=k($,[["render",B]]);export{A as C};
